@@ -2,7 +2,7 @@ package XML::Compile::SOAP::Daemon::Dancer2;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use Dancer2::Plugin;
 use Dancer2::FileUtils 'path';
 use Class::Load qw(try_load_class);
@@ -161,7 +161,7 @@ Pierre VIGIER E<lt>pierre.vigier@gmail.comE<gt>
 
 =head1 CONTRIBUTORS
 
-Mohamad Hallal E<lt>https://github.com/mohdhallal<gt>
+Mohamad Hallal L<https://github.com/mohdhallal>
 
 =head1 COPYRIGHT
 
